# Overview

Over the past few months, the CNCF has witnessed a surge of interest from students eager to participate in our programs. However, at present, the lack of structure around student initiatives presents significant challenges and opportunities for improvement. This repository is dedicated to addressing these challenges and providing a comprehensive solution for the student community. Our goal is to serve as a central hub for students interested in cloud-native technologies, offering resources, support, and guidance to help them thrive in this rapidly evolving field.

This toolkit is for students of any discipline, who already have knowledge of cloud native technologies and want to run events (workshops, talks, show and tells etc.) to help their peers learn more and join the cloud native community. We hope this program will help students learn about cloud native and consider it as an attractive career pathway.

# Mission

Our mission at CNCF Students is to inspire and empower the next generation of cloud-native leaders. We believe in providing opportunities for students to learn and grow their skills in cloud-native technologies and open-source communities.

# What is the benefit to my community?

By building a cloud native community on your campus, you help your fellow students gain access to industry events, like [KubeCon](http://kubecon.io/), utilize a variety of [training resources](https://www.cncf.io/certification/training/), prepare for [paid open source mentorship programs](https://github.com/cncf/mentoring), and even [find jobs after graduation](https://www.cncf.io/blog/2020/12/03/success-story-kubernetes-certifications-help-recent-graduate-stand-out-from-the-crowd-and-quickly-obtain-an-engineering-job/).

# Goals

* Our mission is to cultivate an inclusive environment that fosters collaboration, innovation, and the advancement of cloud-native computing, regardless of students' backgrounds.
* We not only inspire and empower the next generation of cloud-native leaders but also foster a supportive community that encourages the growth and retention of contributors.
* Through the power of open-source, we strive to drive the adoption and growth of cloud-native technologies to make a positive impact on the world.
* We are dedicated to increasing CNCF project participation in mentorship programs by working closing with the `Mentoring WG` and general contributions to encourage the next generation of leaders in the field.
* Our goal is to expand participation in the KubeCon student track to provide a platform for students to showcase their ideas and connect with industry professionals.
* We aim to provide a centralized platform that serves as a one-stop-shop for students seeking to get involved in CNCF communities.
* We plan to establish a mentor-mentee framework that fosters collaboration, communication, and knowledge-sharing among students and industry professionals.
* To sustain our mission, we will develop a path for current students to pass on the torch and onboard new students as they grow, ensuring the continued growth and success of CNCF Students.

# Resources

* [Twitter](https://twitter.com/cncfstudents)
* [Community group](https://community.cncf.io/cloud-native-students)
* [Mentor-mentee framework](./mentor-mentee-framework/README.md)

# Getting started

_The path ahead_

1. Learn the why driving cloud native and making it so impactful
2. Attend the world’s largest open source conference, KubeCon + CloudNativeCon
3. Get introduced to the technical concepts behind cloud native through free training courses
4. Start contributing to open source projects
5. Earn your Kubernetes and Cloud Native Associate Certification
6. Create a local community
7. Apply for paid open source mentorship programs
8. Dive deeper into technical concepts to prepare for certification exams
9. Get certified for cloud native technologies
10. Find a job after graduation

## 1. **Why**

Students joining the cloud native community are setting themselves up for an interesting and potentially lucrative career path. If you don’t know what cloud native computing is, check out these resources.

- [CNCF Charter](https://github.com/cncf/foundation/blob/master/charter.md)

- [Cloud Native Glossary](https://github.com/cncf/glossary)

## 2. **Attend [KubeCon + CloudNativeCon](http://kubecon.io/) and [Kubernetes Community Days](https://github.com/cncf/kubernetes-community-days)**

Students can apply to attend KubeCon + CloudNativeCon and be a part of the largest open source conference in the world. Any student can have a free virtual ticket. You can find the application for [North America](https://events.linuxfoundation.org/kubecon-cloudnativecon-north-america/attend/scholarships/) and [Europe](https://events.linuxfoundation.org/kubecon-cloudnativecon-europe/attend/scholarships/). In addition, students can also apply for a diversity or need based scholarship to attend in person. The conference is held three times a year throughout North America, Europe, and China. Look out for the student track for each one.

Closer to home, [Kubernetes Community Days](https://community.cncf.io/kubernetes-community-days/about-kcd/) offer a great way to get involved in your local cloud native community and meet companies in your area for mentoring, internships, and/or jobs. Most offer free tickets for students.

An opportunity for students to participate in the KubeCon + CloudNativeCon student track is available, allowing them to submit their Call for Proposals (CFP) and share their valuable experiences. As a student, sharing insights and tips can help fellow students excel, making this a great chance to contribute to the community.

## 3. **Free Training courses**

The Linux Foundation has many [free training courses](https://www.edx.org/school/linuxfoundationx) to help prepare you for your journey through cloud native. A few recommended courses are:

- [Introduction to Cloud Infrastructure Technologies](https://www.edx.org/course/introduction-to-cloud-infrastructure-technologies)

- [Introduction to Kubernetes](https://www.edx.org/course/introduction-to-kubernetes)

- [Introduction to DevOps and Site Reliability Engineering](https://www.edx.org/course/introduction-to-devops-and-site-reliability-engineering)

- [Introduction to Service Mesh with Linkerd](https://www.edx.org/course/introduction-to-service-mesh-with-linkerd)

## 4. **Start contributing to open source projects**

Contributing to open source has many benefits from boosting career prospects to making new friends. CNCF has 100s of projects that you can contribute to and there are many places to get started. Good resources are the [Kubernetes contributor site](https://k8s.dev/) and the [CNCF contributor site](https://contribute.cncf.io/). Documentation, contributor experience, and project onboarding are all great places to get started. If English is not your first language, translation is always needed too!

## 5. **Kubernetes and Cloud Native Associate Certification**

Kuberentes and Cloud Native Associate Certification is a multiple-choice certification exam testing entry-level knowledge and skills in Kubernetes and the wider cloud native ecosystem. This exam is intended to demonstrate this knowledge, including how to deploy an application using basic kubectl commands, the architecture of Kubernetes (containers, pods, nodes, clusters), understanding the cloud native landscape and projects (storage, networking, GitOps, service mesh), and understanding the principles of cloud native security. CNCF developed the KCNA to help bring more entry-level talent, like student, into the cloud native community.

- [KCNA Cert Page](https://www.cncf.io/certification/kcna/)

- [Sign up today!](https://training.linuxfoundation.org/certification/kubernetes-cloud-native-associate/)

## 6. **Creating a local community and joining the global student community**

Students can create local chapters on [Cloud Native Community Groups](https://community.cncf.io/) to help organize their local group. You can apply to host a group [here](https://github.com/cncf/communitygroups#how-to-apply) and CNCF has many [best practices](https://github.com/cncf/communitygroups/blob/main/best_practices.md) that you can follow. It is also important to reach out to and work with other student groups in your area like the computer science club or tech companies campus ambassador programs, like [Microsoft Learn Student Ambassadors](https://studentambassadors.microsoft.com/) or [Github Campus Experts](https://education.github.com/experts). Many communities working together makes them all stronger. You can also join the [global student community](https://community.cncf.io/cloud-native-students/) and leverage their community and events for students in your area. Check out the [program ideas](program-ideas.md) for examples of what to do with your local community.

## 7. **Paid mentorship programs**

CNCF participates in a variety of paid mentoring programs to encourage students to consider open source as a career path. CNCF is a great place to spend a semester learning, coding, participating, contributing, and getting paid. You can learn more about which applications are currently open by visiting the [mentoring repo](https://github.com/cncf/mentoring).

## 8. **[In depth training courses](https://training.linuxfoundation.org/)**

Once students have gotten their feet wet with cloud native technologies, CNCF also provides a variety of more in depth training courses including:

- [Introduction to Linux](https://training.linuxfoundation.org/training/introduction-to-linux/)

- [Container Fundamentals](https://training.linuxfoundation.org/training/containers-fundamentals/)

- [Kubernetes Fundamentals](https://training.linuxfoundation.org/training/kubernetes-fundamentals/)

- [Kubernetes for Developers](https://training.linuxfoundation.org/training/kubernetes-for-developers/)

- [Kubernetes Security Essentials](https://training.linuxfoundation.org/training/kubernetes-security-essentials-lfs260/)

- [Monitoring Systems and Services with Prometheus](https://training.linuxfoundation.org/training/monitoring-systems-and-services-with-prometheus-lfs241/)

- [Managing Kubernetes Applications with Helm](https://training.linuxfoundation.org/training/managing-kubernetes-applications-with-helm-lfs244/)

- [Cloud Native Logging with Fluentd](https://training.linuxfoundation.org/training/cloud-native-logging-with-fluentd-lfs242/)

- [Introduction to Kubernetes on Edge](https://training.linuxfoundation.org/training/introduction-to-kubernetes-on-edge-with-k3s-lfs156x/)


## 9. **Getting Certified**

CNCF has three different certifications for people who want to show their experience working with cloud native technologies. These certifications can even lead to [job opportunities after graduation](https://www.cncf.io/blog/2020/12/03/success-story-kubernetes-certifications-help-recent-graduate-stand-out-from-the-crowd-and-quickly-obtain-an-engineering-job/). They are:

- [Certified Kubernetes Administrator CKA](https://training.linuxfoundation.org/certification/certified-kubernetes-administrator-cka/)

- [Certified Kubernetes Application Developer (CKAD)](https://training.linuxfoundation.org/certification/certified-kubernetes-application-developer-ckad/)

- [Certified Kubernetes Security Specialist (CKS)](https://training.linuxfoundation.org/certification/certified-kubernetes-security-specialist/)

- [Prometheus Certified Associate (PCA)](https://training.linuxfoundation.org/certification/prometheus-certified-associate/)

- [Kubernetes And Cloud Security Associate (KCSA)](https://www.cncf.io/certification/kcsa/)

## 10. **Finding a job**

CNCF has [hundreds of members](https://www.cncf.io/about/members/) many of whom are looking to hire people with experience in cloud native technologies. CNCF also has a [job board](https://jobs.cncf.io/) of companies currently hiring.

# Contact

If you wish to engage with CNCF Students, please don't hesitate to share your ideas by submitting a pull request. In case you require assistance, kindly participate in our monthly meeting or reach out to the contact information provided below.

* Github discussions for external communications with participants
    * https://github.com/cncf/students/discussions
* CNCF Slack
    * #students
* Website
    * https://github.com/cncf/students
* Email at students@cncf.io
* For regular meetings, check [Mentoring WG Charter](https://github.com/cncf/tag-contributor-strategy/tree/main/mentoring).

# FAQ

_Who is this toolkit intended for?_

This toolkit is for any student looking to get into the cloud native industry whether they are currently enrolled at a university, attending a boot camp program, are part of a retraining program, or self learning on their own.

_I love this toolkit, but don’t know where to start building my community._

Many campuses have existing student organizations focused on computer science where you may find interested members. Many tech companies also run campus ambassador programs, like [Microsoft Learn Student Ambassadors](https://studentambassadors.microsoft.com/) or [Github Campus Experts](https://education.github.com/experts), that you can join or work with to build communities on your campus. You may also want to connect with your careers center as these skills can lead to job opportunities.

_Who can I reach out to for help?_

CNCF has [Ambassadors](https://github.com/cncf/ambassadors) all around the world with experience organizing local cloud native communities. If you have questions about the program or this toolkit, please contact [students@cncf.io](mailto:students@cncf.io). You can also contact us in the [CNCF slack #students channel](https://cloud-native.slack.com/archives/C01B6B7HM8S) for more information.

_I have an idea for how to make this better. What do I do?_

Please submit an issue or pull request to the GitHub repo or reach out to [students@cncf.io](mailto:students@cncf.io).

# Future

In the times ahead, it would be beneficial to introduce a more formal approach for individuals utilizing the CNCF Students resources such as the Twitter account, community groups, possibly through the submission of a PR. Moreover, the CNCF Students can extend their assistance to aid with local events, appointing student ambassadors, offering training sessions, and other related endeavors.

For more details, check out the [Program Ideas](./program-ideas.md) section.
